" Specify a directory for plugins
" - For Neovim: stdpath('data') . '/plugged'
" - Avoid using standard Vim directory names like 'plugin'
call plug#begin('~/.vim/plugged')

"" Gitvimbim Wrapper
" Vim Fudgeitive
Plug 'tpope/vim-fugitive'
Plug 'shumphrey/fugitive-gitlab.vim'
Plug 'borissov/fugitive-gitea'

"" Coding Assistance
" Ale: Runs fast and works well.
Plug 'dense-analysis/ale'

" deoplete: Ale wants this for code completeopt (fucking dependency hell)
Plug 'Shougo/deoplete.nvim'
Plug 'roxma/nvim-yarp'
Plug 'roxma/vim-hug-neovim-rpc'

" deoplete PHP support
Plug 'phpactor/phpactor' ,  {'do': 'composer install', 'for': 'php'}
Plug 'kristijanhusak/deoplete-phpactor'

" Better HTML PHP support
Plug 'beanworks/vim-phpfmt'

" Guten Tag: Automatically generates ctags (variable names, function, classes)
Plug 'ludovicchabant/vim-gutentags'

" php.vim: PHP syntax higlighting and indent
Plug 'StanAngeloff/php.vim'

" PHP Namespace: Helps to keep track of namespaces and autcompletes them
Plug 'arnaud-lb/vim-php-namespace', {'for': 'php'}

"" Debugger
" v-debug: PHP Debugger with xdebug
Plug 'vim-vdebug/vdebug'

"" GUI
" NERDTree: Sidebar file tree
Plug 'scrooloose/nerdtree'
Plug 'Xuyuanp/nerdtree-git-plugin'

" MINIBUFXPL: A nice buffer explorer
Plug 'fholgado/minibufexpl.vim'

" Airline: Some file infos
Plug 'vim-airline/vim-airline'

"" AutoComplPop: Open the popup menu for autocompletion
"Plug 'vim-scripts/AutoComplPop'

"" Indexing
" ctrlp.vim: Quickly find files by name without navigating
Plug 'kien/ctrlp.vim'

" Ferret: Quickly finds file content
Plug 'wincent/ferret'

"" Input optimization
" Vim Surround: Quickly surround stuff
Plug 'tpope/vim-surround'

" Initialize plugin system
call plug#end()

"" vim config
" Intendation
set tabstop=4
set softtabstop=4
set shiftwidth=4
set expandtab
set autoindent

"" NERDTree config
" Autostart NERDTree on start
autocmd vimenter * NERDTree | wincmd w
let NERDTreeShowHidden=1

" Close vim if the only window left open is a NERDTree
autocmd bufenter * if (winnr("$") == 1 && exists("b:NERDTree") && b:NERDTree.isTabTree()) | q | endif

"" ALE config
" Define fixers
let g:ale_fixers = {
\   '*': ['remove_trailing_lines', 'trim_whitespace'],
\   'javascript': ['eslint'],
\   'php': ['phpcbf']
\}

" Run linter on save
let g:ale_fix_on_save = 1

" Enable ale completion
"let g:ale_completion_enabled = 1

" Overwrite omnicomplete function with ale
"set omnifunc=ale#completion#OmniFunc

" Enable deoplete for Ale
let g:deoplete#enable_at_startup = 1
let g:deoplete#ignore_sources = get(g:, 'deoplete#ignore_sources', {})
let g:deoplete#ignore_sources = ['omni']

"" Gutentags
" Auto generate ctags on startup
autocmd! User vim-gutentags call gutentags#setup_gutentags()

"" PHP
" PHP Namespace: Automatically use fully qualified name
function! IPhpExpandClass()
    call PhpExpandClass()
    call feedkeys('a', 'n')
endfunction
autocmd FileType php inoremap <Leader>e <Esc>:call IPhpExpandClass()<CR>
autocmd FileType php noremap <Leader>e :call PhpExpandClass()<CR>

"" vdebug config
" Set xdebug config
let g:vdebug_options = {'ide_key': 'PHPSTORM'}
let g:vdebug_options = {'break_on_open': 0}
let g:vdebug_options = {'server': '172.17.0.1'}
let g:vdebug_options = {'port': '9002'}

" Configure paths
let g:vdebug_options["path_maps"] = { "/var/www/html": "/home/leong/workspace/upwire-2019" }

" Don't break on open
let g:vdebug_options['break_on_open'] = 0

"" CtrlP config
" Self explainatory
let g:ctrlp_max_files=0
let g:ctrlp_max_depth=40
let g:ctrlp_custom_ignore = 'node_modules\|DS_Store\|git'

"" Vim Config
" Some autocompletion settings.
set completeopt+=longest,menuone,menu,preview
